# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_appinfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(steammessages_clientserver_appinfo.proto\x1a\x18steammessages_base.proto\"M\n\x17\x43MsgClientAppInfoUpdate\x12\x19\n\x11last_changenumber\x18\x01 \x01(\r\x12\x17\n\x0fsend_changelist\x18\x02 \x01(\x08\"d\n\x18\x43MsgClientAppInfoChanges\x12\x1d\n\x15\x63urrent_change_number\x18\x01 \x01(\r\x12\x19\n\x11\x66orce_full_update\x18\x02 \x01(\x08\x12\x0e\n\x06\x61ppIDs\x18\x03 \x03(\r\"\xab\x01\n\x18\x43MsgClientAppInfoRequest\x12+\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x1d.CMsgClientAppInfoRequest.App\x12\x1f\n\x10supports_batches\x18\x02 \x01(\x08:\x05\x66\x61lse\x1a\x41\n\x03\x41pp\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsection_flags\x18\x02 \x01(\r\x12\x13\n\x0bsection_CRC\x18\x03 \x03(\r\"\xc0\x01\n!CMsgClientPICSChangesSinceRequest\x12\x1b\n\x13since_change_number\x18\x01 \x01(\r\x12\x1d\n\x15send_app_info_changes\x18\x02 \x01(\x08\x12!\n\x19send_package_info_changes\x18\x03 \x01(\x08\x12\x1b\n\x13num_app_info_cached\x18\x04 \x01(\r\x12\x1f\n\x17num_package_info_cached\x18\x05 \x01(\r\"\xe5\x03\n\"CMsgClientPICSChangesSinceResponse\x12\x1d\n\x15\x63urrent_change_number\x18\x01 \x01(\r\x12\x1b\n\x13since_change_number\x18\x02 \x01(\r\x12\x19\n\x11\x66orce_full_update\x18\x03 \x01(\x08\x12J\n\x0fpackage_changes\x18\x04 \x03(\x0b\x32\x31.CMsgClientPICSChangesSinceResponse.PackageChange\x12\x42\n\x0b\x61pp_changes\x18\x05 \x03(\x0b\x32-.CMsgClientPICSChangesSinceResponse.AppChange\x12\x1d\n\x15\x66orce_full_app_update\x18\x06 \x01(\x08\x12!\n\x19\x66orce_full_package_update\x18\x07 \x01(\x08\x1aN\n\rPackageChange\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x13\n\x0bneeds_token\x18\x03 \x01(\x08\x1a\x46\n\tAppChange\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x13\n\x0bneeds_token\x18\x03 \x01(\x08\"\xaf\x03\n CMsgClientPICSProductInfoRequest\x12?\n\x08packages\x18\x01 \x03(\x0b\x32-.CMsgClientPICSProductInfoRequest.PackageInfo\x12\x37\n\x04\x61pps\x18\x02 \x03(\x0b\x32).CMsgClientPICSProductInfoRequest.AppInfo\x12\x16\n\x0emeta_data_only\x18\x03 \x01(\x08\x12\x17\n\x0fnum_prev_failed\x18\x04 \x01(\r\x12(\n OBSOLETE_supports_package_tokens\x18\x05 \x01(\r\x12\x17\n\x0fsequence_number\x18\x06 \x01(\r\x12\x17\n\x0fsingle_response\x18\x07 \x01(\x08\x1aL\n\x07\x41ppInfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\x12\x1c\n\x14only_public_obsolete\x18\x03 \x01(\x08\x1a\x36\n\x0bPackageInfo\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\"\xb9\x04\n!CMsgClientPICSProductInfoResponse\x12\x38\n\x04\x61pps\x18\x01 \x03(\x0b\x32*.CMsgClientPICSProductInfoResponse.AppInfo\x12\x16\n\x0eunknown_appids\x18\x02 \x03(\r\x12@\n\x08packages\x18\x03 \x03(\x0b\x32..CMsgClientPICSProductInfoResponse.PackageInfo\x12\x1a\n\x12unknown_packageids\x18\x04 \x03(\r\x12\x16\n\x0emeta_data_only\x18\x05 \x01(\x08\x12\x18\n\x10response_pending\x18\x06 \x01(\x08\x12\x15\n\rhttp_min_size\x18\x07 \x01(\r\x12\x11\n\thttp_host\x18\x08 \x01(\t\x1a\x86\x01\n\x07\x41ppInfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x15\n\rmissing_token\x18\x03 \x01(\x08\x12\x0b\n\x03sha\x18\x04 \x01(\x0c\x12\x0e\n\x06\x62uffer\x18\x05 \x01(\x0c\x12\x13\n\x0bonly_public\x18\x06 \x01(\x08\x12\x0c\n\x04size\x18\x07 \x01(\r\x1ay\n\x0bPackageInfo\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x15\n\rmissing_token\x18\x03 \x01(\x08\x12\x0b\n\x03sha\x18\x04 \x01(\x0c\x12\x0e\n\x06\x62uffer\x18\x05 \x01(\x0c\x12\x0c\n\x04size\x18\x06 \x01(\r:\x04\x88\xb5\x18\x00\"F\n CMsgClientPICSAccessTokenRequest\x12\x12\n\npackageids\x18\x01 \x03(\r\x12\x0e\n\x06\x61ppids\x18\x02 \x03(\r\"\xdf\x02\n!CMsgClientPICSAccessTokenResponse\x12N\n\x15package_access_tokens\x18\x01 \x03(\x0b\x32/.CMsgClientPICSAccessTokenResponse.PackageToken\x12\x1d\n\x15package_denied_tokens\x18\x02 \x03(\r\x12\x46\n\x11\x61pp_access_tokens\x18\x03 \x03(\x0b\x32+.CMsgClientPICSAccessTokenResponse.AppToken\x12\x19\n\x11\x61pp_denied_tokens\x18\x04 \x03(\r\x1a\x37\n\x0cPackageToken\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\x1a/\n\x08\x41ppToken\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\"q\n CMsgClientPICSPrivateBetaRequest\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\x12\x11\n\tbeta_name\x18\x03 \x01(\t\x12\x15\n\rpassword_hash\x18\x04 \x01(\x0c\"N\n!CMsgClientPICSPrivateBetaResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x15\n\rdepot_section\x18\x02 \x01(\x0c\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_appinfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTPICSPRODUCTINFORESPONSE._options = None
  _CMSGCLIENTPICSPRODUCTINFORESPONSE._serialized_options = b'\210\265\030\000'
  _CMSGCLIENTAPPINFOUPDATE._serialized_start=70
  _CMSGCLIENTAPPINFOUPDATE._serialized_end=147
  _CMSGCLIENTAPPINFOCHANGES._serialized_start=149
  _CMSGCLIENTAPPINFOCHANGES._serialized_end=249
  _CMSGCLIENTAPPINFOREQUEST._serialized_start=252
  _CMSGCLIENTAPPINFOREQUEST._serialized_end=423
  _CMSGCLIENTAPPINFOREQUEST_APP._serialized_start=358
  _CMSGCLIENTAPPINFOREQUEST_APP._serialized_end=423
  _CMSGCLIENTPICSCHANGESSINCEREQUEST._serialized_start=426
  _CMSGCLIENTPICSCHANGESSINCEREQUEST._serialized_end=618
  _CMSGCLIENTPICSCHANGESSINCERESPONSE._serialized_start=621
  _CMSGCLIENTPICSCHANGESSINCERESPONSE._serialized_end=1106
  _CMSGCLIENTPICSCHANGESSINCERESPONSE_PACKAGECHANGE._serialized_start=956
  _CMSGCLIENTPICSCHANGESSINCERESPONSE_PACKAGECHANGE._serialized_end=1034
  _CMSGCLIENTPICSCHANGESSINCERESPONSE_APPCHANGE._serialized_start=1036
  _CMSGCLIENTPICSCHANGESSINCERESPONSE_APPCHANGE._serialized_end=1106
  _CMSGCLIENTPICSPRODUCTINFOREQUEST._serialized_start=1109
  _CMSGCLIENTPICSPRODUCTINFOREQUEST._serialized_end=1540
  _CMSGCLIENTPICSPRODUCTINFOREQUEST_APPINFO._serialized_start=1408
  _CMSGCLIENTPICSPRODUCTINFOREQUEST_APPINFO._serialized_end=1484
  _CMSGCLIENTPICSPRODUCTINFOREQUEST_PACKAGEINFO._serialized_start=1486
  _CMSGCLIENTPICSPRODUCTINFOREQUEST_PACKAGEINFO._serialized_end=1540
  _CMSGCLIENTPICSPRODUCTINFORESPONSE._serialized_start=1543
  _CMSGCLIENTPICSPRODUCTINFORESPONSE._serialized_end=2112
  _CMSGCLIENTPICSPRODUCTINFORESPONSE_APPINFO._serialized_start=1849
  _CMSGCLIENTPICSPRODUCTINFORESPONSE_APPINFO._serialized_end=1983
  _CMSGCLIENTPICSPRODUCTINFORESPONSE_PACKAGEINFO._serialized_start=1985
  _CMSGCLIENTPICSPRODUCTINFORESPONSE_PACKAGEINFO._serialized_end=2106
  _CMSGCLIENTPICSACCESSTOKENREQUEST._serialized_start=2114
  _CMSGCLIENTPICSACCESSTOKENREQUEST._serialized_end=2184
  _CMSGCLIENTPICSACCESSTOKENRESPONSE._serialized_start=2187
  _CMSGCLIENTPICSACCESSTOKENRESPONSE._serialized_end=2538
  _CMSGCLIENTPICSACCESSTOKENRESPONSE_PACKAGETOKEN._serialized_start=2434
  _CMSGCLIENTPICSACCESSTOKENRESPONSE_PACKAGETOKEN._serialized_end=2489
  _CMSGCLIENTPICSACCESSTOKENRESPONSE_APPTOKEN._serialized_start=2491
  _CMSGCLIENTPICSACCESSTOKENRESPONSE_APPTOKEN._serialized_end=2538
  _CMSGCLIENTPICSPRIVATEBETAREQUEST._serialized_start=2540
  _CMSGCLIENTPICSPRIVATEBETAREQUEST._serialized_end=2653
  _CMSGCLIENTPICSPRIVATEBETARESPONSE._serialized_start=2655
  _CMSGCLIENTPICSPRIVATEBETARESPONSE._serialized_end=2733
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: content_manifest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ontent_manifest.proto\"\xef\x02\n\x16\x43ontentManifestPayload\x12\x35\n\x08mappings\x18\x01 \x03(\x0b\x32#.ContentManifestPayload.FileMapping\x1a\x9d\x02\n\x0b\x46ileMapping\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x14\n\x0csha_filename\x18\x04 \x01(\x0c\x12\x13\n\x0bsha_content\x18\x05 \x01(\x0c\x12=\n\x06\x63hunks\x18\x06 \x03(\x0b\x32-.ContentManifestPayload.FileMapping.ChunkData\x12\x12\n\nlinktarget\x18\x07 \x01(\t\x1a\x61\n\tChunkData\x12\x0b\n\x03sha\x18\x01 \x01(\x0c\x12\x0b\n\x03\x63rc\x18\x02 \x01(\x07\x12\x0e\n\x06offset\x18\x03 \x01(\x04\x12\x13\n\x0b\x63\x62_original\x18\x04 \x01(\r\x12\x15\n\rcb_compressed\x18\x05 \x01(\r\"\xec\x01\n\x17\x43ontentManifestMetadata\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x14\n\x0cgid_manifest\x18\x02 \x01(\x04\x12\x15\n\rcreation_time\x18\x03 \x01(\r\x12\x1b\n\x13\x66ilenames_encrypted\x18\x04 \x01(\x08\x12\x18\n\x10\x63\x62_disk_original\x18\x05 \x01(\x04\x12\x1a\n\x12\x63\x62_disk_compressed\x18\x06 \x01(\x04\x12\x15\n\runique_chunks\x18\x07 \x01(\r\x12\x15\n\rcrc_encrypted\x18\x08 \x01(\r\x12\x11\n\tcrc_clear\x18\t \x01(\r\"-\n\x18\x43ontentManifestSignature\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\x84\x03\n\x12\x43ontentDeltaChunks\x12\x10\n\x08\x64\x65pot_id\x18\x01 \x01(\r\x12\x1a\n\x12manifest_id_source\x18\x02 \x01(\x04\x12\x1a\n\x12manifest_id_target\x18\x03 \x01(\x04\x12\x33\n\x0b\x64\x65ltaChunks\x18\x04 \x03(\x0b\x32\x1e.ContentDeltaChunks.DeltaChunk\x12h\n\x13\x63hunk_data_location\x18\x05 \x01(\x0e\x32\x1f.EContentDeltaChunkDataLocation:*k_EContentDeltaChunkDataLocationInProtobuf\x1a\x84\x01\n\nDeltaChunk\x12\x12\n\nsha_source\x18\x01 \x01(\x0c\x12\x12\n\nsha_target\x18\x02 \x01(\x0c\x12\x15\n\rsize_original\x18\x03 \x01(\r\x12\x14\n\x0cpatch_method\x18\x04 \x01(\r\x12\r\n\x05\x63hunk\x18\x05 \x01(\x0c\x12\x12\n\nsize_delta\x18\x06 \x01(\r*\x83\x01\n\x1e\x45\x43ontentDeltaChunkDataLocation\x12.\n*k_EContentDeltaChunkDataLocationInProtobuf\x10\x00\x12\x31\n-k_EContentDeltaChunkDataLocationAfterProtobuf\x10\x01\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'content_manifest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _ECONTENTDELTACHUNKDATALOCATION._serialized_start=1074
  _ECONTENTDELTACHUNKDATALOCATION._serialized_end=1205
  _CONTENTMANIFESTPAYLOAD._serialized_start=27
  _CONTENTMANIFESTPAYLOAD._serialized_end=394
  _CONTENTMANIFESTPAYLOAD_FILEMAPPING._serialized_start=109
  _CONTENTMANIFESTPAYLOAD_FILEMAPPING._serialized_end=394
  _CONTENTMANIFESTPAYLOAD_FILEMAPPING_CHUNKDATA._serialized_start=297
  _CONTENTMANIFESTPAYLOAD_FILEMAPPING_CHUNKDATA._serialized_end=394
  _CONTENTMANIFESTMETADATA._serialized_start=397
  _CONTENTMANIFESTMETADATA._serialized_end=633
  _CONTENTMANIFESTSIGNATURE._serialized_start=635
  _CONTENTMANIFESTSIGNATURE._serialized_end=680
  _CONTENTDELTACHUNKS._serialized_start=683
  _CONTENTDELTACHUNKS._serialized_end=1071
  _CONTENTDELTACHUNKS_DELTACHUNK._serialized_start=939
  _CONTENTDELTACHUNKS_DELTACHUNK._serialized_end=1071
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_leds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18webuimessages_leds.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"/\n\x0c\x43MsgLEDColor\x12\t\n\x01r\x18\x01 \x01(\x02\x12\t\n\x01g\x18\x02 \x01(\x02\x12\t\n\x01\x62\x18\x03 \x01(\x02\"\xfa\x01\n\x14\x43MsgLEDManagerDevice\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11\x65\x66\x66\x65\x63ts_available\x18\x04 \x03(\t\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x05 \x01(\t\x12\x16\n\x0esupports_color\x18\t \x01(\x08\x12\x1c\n\x05\x63olor\x18\n \x01(\x0b\x32\r.CMsgLEDColor\x12\x16\n\x0esupports_speed\x18\x0b \x01(\x08\x12\r\n\x05speed\x18\x0c \x01(\x02\x12\x1b\n\x13supports_brightness\x18\r \x01(\x08\x12\x12\n\nbrightness\x18\x0e \x01(\x02\"[\n\x13\x43MsgLEDManagerState\x12\x1c\n\x14is_service_available\x18\x01 \x01(\x08\x12&\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32\x15.CMsgLEDManagerDevice\"\x1e\n\x1c\x43LEDManager_GetState_Request\"D\n\x1d\x43LEDManager_GetState_Response\x12#\n\x05state\x18\x01 \x01(\x0b\x32\x14.CMsgLEDManagerState\"\'\n%CLEDManager_StateChanged_Notification\"O\n\x1c\x43LEDManager_SetColor_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x1c\n\x05\x63olor\x18\x02 \x01(\x0b\x32\r.CMsgLEDColor\"\x1f\n\x1d\x43LEDManager_SetColor_Response\"D\n\x1e\x43LEDManager_SetEnabled_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"!\n\x1f\x43LEDManager_SetEnabled_Response\"B\n\x1d\x43LEDManager_SetEffect_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\t\" \n\x1e\x43LEDManager_SetEffect_Response\"@\n\x1c\x43LEDManager_SetSpeed_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\r\n\x05speed\x18\x02 \x01(\x02\"\x1f\n\x1d\x43LEDManager_SetSpeed_Response\"J\n!CLEDManager_SetBrightness_Request\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x12\n\nbrightness\x18\x02 \x01(\x02\"$\n\"CLEDManager_SetBrightness_Response2\xbc\x04\n\nLEDManager\x12I\n\x08GetState\x12\x1d.CLEDManager_GetState_Request\x1a\x1e.CLEDManager_GetState_Response\x12N\n\x12NotifyStateChanged\x12&.CLEDManager_StateChanged_Notification\x1a\x10.WebUINoResponse\x12O\n\nSetEnabled\x12\x1f.CLEDManager_SetEnabled_Request\x1a .CLEDManager_SetEnabled_Response\x12I\n\x08SetColor\x12\x1d.CLEDManager_SetColor_Request\x1a\x1e.CLEDManager_SetColor_Response\x12L\n\tSetEffect\x12\x1e.CLEDManager_SetEffect_Request\x1a\x1f.CLEDManager_SetEffect_Response\x12I\n\x08SetSpeed\x12\x1d.CLEDManager_SetSpeed_Request\x1a\x1e.CLEDManager_SetSpeed_Response\x12X\n\rSetBrightness\x12\".CLEDManager_SetBrightness_Request\x1a#.CLEDManager_SetBrightness_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_leds_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _LEDMANAGER._options = None
  _LEDMANAGER._serialized_options = b'\200\227\"\001'
  _CMSGLEDCOLOR._serialized_start=93
  _CMSGLEDCOLOR._serialized_end=140
  _CMSGLEDMANAGERDEVICE._serialized_start=143
  _CMSGLEDMANAGERDEVICE._serialized_end=393
  _CMSGLEDMANAGERSTATE._serialized_start=395
  _CMSGLEDMANAGERSTATE._serialized_end=486
  _CLEDMANAGER_GETSTATE_REQUEST._serialized_start=488
  _CLEDMANAGER_GETSTATE_REQUEST._serialized_end=518
  _CLEDMANAGER_GETSTATE_RESPONSE._serialized_start=520
  _CLEDMANAGER_GETSTATE_RESPONSE._serialized_end=588
  _CLEDMANAGER_STATECHANGED_NOTIFICATION._serialized_start=590
  _CLEDMANAGER_STATECHANGED_NOTIFICATION._serialized_end=629
  _CLEDMANAGER_SETCOLOR_REQUEST._serialized_start=631
  _CLEDMANAGER_SETCOLOR_REQUEST._serialized_end=710
  _CLEDMANAGER_SETCOLOR_RESPONSE._serialized_start=712
  _CLEDMANAGER_SETCOLOR_RESPONSE._serialized_end=743
  _CLEDMANAGER_SETENABLED_REQUEST._serialized_start=745
  _CLEDMANAGER_SETENABLED_REQUEST._serialized_end=813
  _CLEDMANAGER_SETENABLED_RESPONSE._serialized_start=815
  _CLEDMANAGER_SETENABLED_RESPONSE._serialized_end=848
  _CLEDMANAGER_SETEFFECT_REQUEST._serialized_start=850
  _CLEDMANAGER_SETEFFECT_REQUEST._serialized_end=916
  _CLEDMANAGER_SETEFFECT_RESPONSE._serialized_start=918
  _CLEDMANAGER_SETEFFECT_RESPONSE._serialized_end=950
  _CLEDMANAGER_SETSPEED_REQUEST._serialized_start=952
  _CLEDMANAGER_SETSPEED_REQUEST._serialized_end=1016
  _CLEDMANAGER_SETSPEED_RESPONSE._serialized_start=1018
  _CLEDMANAGER_SETSPEED_RESPONSE._serialized_end=1049
  _CLEDMANAGER_SETBRIGHTNESS_REQUEST._serialized_start=1051
  _CLEDMANAGER_SETBRIGHTNESS_REQUEST._serialized_end=1125
  _CLEDMANAGER_SETBRIGHTNESS_RESPONSE._serialized_start=1127
  _CLEDMANAGER_SETBRIGHTNESS_RESPONSE._serialized_end=1163
  _LEDMANAGER._serialized_start=1166
  _LEDMANAGER._serialized_end=1738
_builder.BuildServices(DESCRIPTOR, 'webuimessages_leds_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_player.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asteammessages_player.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\"D\n1CPlayer_GetRecentPlaytimeSessionsForChild_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\"\xfe\x01\n2CPlayer_GetRecentPlaytimeSessionsForChild_Response\x12U\n\x08sessions\x18\x01 \x03(\x0b\x32\x43.CPlayer_GetRecentPlaytimeSessionsForChild_Response.PlaytimeSession\x1aq\n\x0fPlaytimeSession\x12\x12\n\ntime_start\x18\x01 \x01(\r\x12\x10\n\x08time_end\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\r\x12\x14\n\x0c\x64isconnected\x18\x05 \x01(\x08\"8\n$CPlayer_GetPlayerLinkDetails_Request\x12\x10\n\x08steamids\x18\x01 \x03(\x04\"\xc5\t\n%CPlayer_GetPlayerLinkDetails_Response\x12J\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x38.CPlayer_GetPlayerLinkDetails_Response.PlayerLinkDetails\x1a\xcf\x08\n\x11PlayerLinkDetails\x12_\n\x0bpublic_data\x18\x01 \x01(\x0b\x32J.CPlayer_GetPlayerLinkDetails_Response.PlayerLinkDetails.AccountPublicData\x12\x61\n\x0cprivate_data\x18\x02 \x01(\x0b\x32K.CPlayer_GetPlayerLinkDetails_Response.PlayerLinkDetails.AccountPrivateData\x1a\x87\x02\n\x11\x41\x63\x63ountPublicData\x12\x0f\n\x07steamid\x18\x01 \x02(\x06\x12\x18\n\x10visibility_state\x18\x02 \x01(\x05\x12\x15\n\rprivacy_state\x18\x03 \x01(\x05\x12\x15\n\rprofile_state\x18\x04 \x01(\x05\x12\x18\n\x10\x62\x61n_expires_time\x18\x07 \x01(\r\x12\x15\n\raccount_flags\x18\x08 \x01(\r\x12\x19\n\x11sha_digest_avatar\x18\t \x01(\x0c\x12\x14\n\x0cpersona_name\x18\n \x01(\t\x12\x13\n\x0bprofile_url\x18\x0b \x01(\t\x12\"\n\x1a\x63ontent_country_restricted\x18\x0c \x01(\x08\x1a\xeb\x04\n\x12\x41\x63\x63ountPrivateData\x12\x15\n\rpersona_state\x18\x01 \x01(\x05\x12\x1b\n\x13persona_state_flags\x18\x02 \x01(\r\x12\x14\n\x0ctime_created\x18\x03 \x01(\r\x12\x0f\n\x07game_id\x18\x04 \x01(\x06\x12\x1c\n\x14game_server_steam_id\x18\x05 \x01(\x06\x12\x1e\n\x16game_server_ip_address\x18\x06 \x01(\r\x12\x18\n\x10game_server_port\x18\x07 \x01(\r\x12\x17\n\x0fgame_extra_info\x18\x08 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\t \x01(\t\x12\x16\n\x0elobby_steam_id\x18\n \x01(\x06\x12\x18\n\x10rich_presence_kv\x18\x0b \x01(\t\x12\x1c\n\x14\x62roadcast_session_id\x18\x0c \x01(\x06\x12$\n\x1cwatching_broadcast_accountid\x18\r \x01(\r\x12 \n\x18watching_broadcast_appid\x18\x0e \x01(\r\x12\"\n\x1awatching_broadcast_viewers\x18\x0f \x01(\r\x12 \n\x18watching_broadcast_title\x18\x10 \x01(\t\x12\x18\n\x10last_logoff_time\x18\x11 \x01(\r\x12\x18\n\x10last_seen_online\x18\x12 \x01(\r\x12\x14\n\x0cgame_os_type\x18\x13 \x01(\x05\x12\x18\n\x10game_device_type\x18\x14 \x01(\x05\x12\x18\n\x10game_device_name\x18\x15 \x01(\t\x12\x17\n\x0fgame_is_private\x18\x16 \x01(\x08\"4\n2CPlayer_GetMutualFriendsForIncomingInvites_Request\"\\\n&CPlayer_IncomingInviteMutualFriendList\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12!\n\x19mutual_friend_account_ids\x18\x02 \x03(\r\"\x8c\x01\n3CPlayer_GetMutualFriendsForIncomingInvites_Response\x12U\n$incoming_invite_mutual_friends_lists\x18\x01 \x03(\x0b\x32\'.CPlayer_IncomingInviteMutualFriendList\"\xf3\x01\n\x1d\x43Player_GetOwnedGames_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x17\n\x0finclude_appinfo\x18\x02 \x01(\x08\x12!\n\x19include_played_free_games\x18\x03 \x01(\x08\x12\x15\n\rappids_filter\x18\x04 \x03(\r\x12\x18\n\x10include_free_sub\x18\x05 \x01(\x08\x12 \n\x12skip_unvetted_apps\x18\x06 \x01(\x08:\x04true\x12\x10\n\x08language\x18\x07 \x01(\t\x12 \n\x18include_extended_appinfo\x18\x08 \x01(\x08\"\xd5\x04\n\x1e\x43Player_GetOwnedGames_Response\x12\x12\n\ngame_count\x18\x01 \x01(\r\x12\x33\n\x05games\x18\x02 \x03(\x0b\x32$.CPlayer_GetOwnedGames_Response.Game\x1a\xe9\x03\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fplaytime_2weeks\x18\x03 \x01(\x05\x12\x18\n\x10playtime_forever\x18\x04 \x01(\x05\x12\x14\n\x0cimg_icon_url\x18\x05 \x01(\t\x12#\n\x1bhas_community_visible_stats\x18\x07 \x01(\x08\x12 \n\x18playtime_windows_forever\x18\x08 \x01(\x05\x12\x1c\n\x14playtime_mac_forever\x18\t \x01(\x05\x12\x1e\n\x16playtime_linux_forever\x18\n \x01(\x05\x12\x1d\n\x15playtime_deck_forever\x18\x14 \x01(\x05\x12\x19\n\x11rtime_last_played\x18\x0b \x01(\r\x12\x18\n\x10\x63\x61psule_filename\x18\x0c \x01(\t\x12\x0f\n\x07sort_as\x18\r \x01(\t\x12\x14\n\x0chas_workshop\x18\x0e \x01(\x08\x12\x12\n\nhas_market\x18\x0f \x01(\x08\x12\x0f\n\x07has_dlc\x18\x10 \x01(\x08\x12\x18\n\x10has_leaderboards\x18\x11 \x01(\x08\x12\x1d\n\x15\x63ontent_descriptorids\x18\x12 \x03(\r\x12\x1d\n\x15playtime_disconnected\x18\x13 \x01(\x05\"M\n\x1b\x43Player_GetPlayNext_Request\x12\x17\n\x0fmax_age_seconds\x18\x01 \x01(\r\x12\x15\n\rignore_appids\x18\x02 \x03(\r\"H\n\x1c\x43Player_GetPlayNext_Response\x12\x18\n\x10last_update_time\x18\x01 \x01(\r\x12\x0e\n\x06\x61ppids\x18\x02 \x03(\r\"7\n&CPlayer_GetFriendsGameplayInfo_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xee\x05\n\'CPlayer_GetFriendsGameplayInfo_Response\x12K\n\tyour_info\x18\x01 \x01(\x0b\x32\x38.CPlayer_GetFriendsGameplayInfo_Response.OwnGameplayInfo\x12M\n\x07in_game\x18\x02 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12U\n\x0fplayed_recently\x18\x03 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12Q\n\x0bplayed_ever\x18\x04 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12J\n\x04owns\x18\x05 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x12Q\n\x0bin_wishlist\x18\x06 \x03(\x0b\x32<.CPlayer_GetFriendsGameplayInfo_Response.FriendsGameplayInfo\x1a^\n\x13\x46riendsGameplayInfo\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x16\n\x0eminutes_played\x18\x02 \x01(\r\x12\x1e\n\x16minutes_played_forever\x18\x03 \x01(\r\x1a~\n\x0fOwnGameplayInfo\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x16\n\x0eminutes_played\x18\x02 \x01(\r\x12\x1e\n\x16minutes_played_forever\x18\x03 \x01(\r\x12\x13\n\x0bin_wishlist\x18\x04 \x01(\x08\x12\r\n\x05owned\x18\x05 \x01(\x08\"3\n\"CPlayer_GetGameBadgeLevels_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xb5\x01\n#CPlayer_GetGameBadgeLevels_Response\x12\x14\n\x0cplayer_level\x18\x01 \x01(\r\x12:\n\x06\x62\x61\x64ges\x18\x02 \x03(\x0b\x32*.CPlayer_GetGameBadgeLevels_Response.Badge\x1a<\n\x05\x42\x61\x64ge\x12\r\n\x05level\x18\x01 \x01(\x05\x12\x0e\n\x06series\x18\x02 \x01(\x05\x12\x14\n\x0c\x62order_color\x18\x03 \x01(\r\"I\n$CPlayer_GetProfileBackground_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08language\x18\x02 \x01(\t\"\xa9\x03\n\x0bProfileItem\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\x12\x13\n\x0bimage_small\x18\x02 \x01(\t\x12\x13\n\x0bimage_large\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x12\n\nitem_title\x18\x05 \x01(\t\x12\x18\n\x10item_description\x18\x06 \x01(\t\x12\r\n\x05\x61ppid\x18\x07 \x01(\r\x12\x11\n\titem_type\x18\x08 \x01(\r\x12\x12\n\nitem_class\x18\t \x01(\r\x12\x12\n\nmovie_webm\x18\n \x01(\t\x12\x11\n\tmovie_mp4\x18\x0b \x01(\t\x12\x18\n\x10movie_webm_small\x18\r \x01(\t\x12\x17\n\x0fmovie_mp4_small\x18\x0e \x01(\t\x12\x16\n\x0e\x65quipped_flags\x18\x0c \x01(\r\x12\x31\n\x0eprofile_colors\x18\x0f \x03(\x0b\x32\x19.ProfileItem.ProfileColor\x12\r\n\x05tiled\x18\x10 \x01(\x08\x1a\x31\n\x0cProfileColor\x12\x12\n\nstyle_name\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\"Q\n%CPlayer_GetProfileBackground_Response\x12(\n\x12profile_background\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"?\n$CPlayer_SetProfileBackground_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"\'\n%CPlayer_SetProfileBackground_Response\"M\n(CPlayer_GetMiniProfileBackground_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08language\x18\x02 \x01(\t\"U\n)CPlayer_GetMiniProfileBackground_Response\x12(\n\x12profile_background\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"C\n(CPlayer_SetMiniProfileBackground_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"+\n)CPlayer_SetMiniProfileBackground_Response\"C\n\x1e\x43Player_GetAvatarFrame_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08language\x18\x02 \x01(\t\"E\n\x1f\x43Player_GetAvatarFrame_Response\x12\"\n\x0c\x61vatar_frame\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"9\n\x1e\x43Player_SetAvatarFrame_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"!\n\x1f\x43Player_SetAvatarFrame_Response\"F\n!CPlayer_GetAnimatedAvatar_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08language\x18\x02 \x01(\t\"B\n\"CPlayer_GetAnimatedAvatar_Response\x12\x1c\n\x06\x61vatar\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"<\n!CPlayer_SetAnimatedAvatar_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"$\n\"CPlayer_SetAnimatedAvatar_Response\"M\n(CPlayer_GetSteamDeckKeyboardSkin_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08language\x18\x02 \x01(\t\"[\n)CPlayer_GetSteamDeckKeyboardSkin_Response\x12.\n\x18steam_deck_keyboard_skin\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\"C\n(CPlayer_SetSteamDeckKeyboardSkin_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\"+\n)CPlayer_SetSteamDeckKeyboardSkin_Response\"_\n$CPlayer_GetProfileItemsOwned_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12%\n\x07\x66ilters\x18\x02 \x03(\x0e\x32\x14.ECommunityItemClass\"\xda\x02\n%CPlayer_GetProfileItemsOwned_Response\x12)\n\x13profile_backgrounds\x18\x01 \x03(\x0b\x32\x0c.ProfileItem\x12.\n\x18mini_profile_backgrounds\x18\x02 \x03(\x0b\x32\x0c.ProfileItem\x12#\n\ravatar_frames\x18\x03 \x03(\x0b\x32\x0c.ProfileItem\x12&\n\x10\x61nimated_avatars\x18\x04 \x03(\x0b\x32\x0c.ProfileItem\x12\'\n\x11profile_modifiers\x18\x05 \x03(\x0b\x32\x0c.ProfileItem\x12/\n\x19steam_deck_keyboard_skins\x18\x06 \x03(\x0b\x32\x0c.ProfileItem\x12/\n\x19steam_deck_startup_movies\x18\x07 \x03(\x0b\x32\x0c.ProfileItem\"L\n\'CPlayer_GetProfileItemsEquipped_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08language\x18\x02 \x01(\t\"\xa6\x02\n(CPlayer_GetProfileItemsEquipped_Response\x12(\n\x12profile_background\x18\x01 \x01(\x0b\x32\x0c.ProfileItem\x12-\n\x17mini_profile_background\x18\x02 \x01(\x0b\x32\x0c.ProfileItem\x12\"\n\x0c\x61vatar_frame\x18\x03 \x01(\x0b\x32\x0c.ProfileItem\x12%\n\x0f\x61nimated_avatar\x18\x04 \x01(\x0b\x32\x0c.ProfileItem\x12&\n\x10profile_modifier\x18\x05 \x01(\x0b\x32\x0c.ProfileItem\x12.\n\x18steam_deck_keyboard_skin\x18\x06 \x01(\x0b\x32\x0c.ProfileItem\"U\n+CPlayer_SetEquippedProfileItemFlags_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\r\".\n,CPlayer_SetEquippedProfileItemFlags_Response\"!\n\x1f\x43Player_GetEmoticonList_Request\"\xdb\x01\n CPlayer_GetEmoticonList_Response\x12=\n\temoticons\x18\x01 \x03(\x0b\x32*.CPlayer_GetEmoticonList_Response.Emoticon\x1ax\n\x08\x45moticon\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x16\n\x0etime_last_used\x18\x03 \x01(\r\x12\x11\n\tuse_count\x18\x04 \x01(\r\x12\x15\n\rtime_received\x18\x05 \x01(\r\x12\r\n\x05\x61ppid\x18\x06 \x01(\r\"M\n)CPlayer_GetCommunityBadgeProgress_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x0f\n\x07\x62\x61\x64geid\x18\x02 \x01(\x05\"\x9c\x01\n*CPlayer_GetCommunityBadgeProgress_Response\x12\x41\n\x06quests\x18\x01 \x03(\x0b\x32\x31.CPlayer_GetCommunityBadgeProgress_Response.Quest\x1a+\n\x05Quest\x12\x0f\n\x07questid\x18\x01 \x01(\r\x12\x11\n\tcompleted\x18\x02 \x01(\x08\"y\n*CPlayer_GetTopAchievementsForGames_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x18\n\x10max_achievements\x18\x03 \x01(\r\x12\x0e\n\x06\x61ppids\x18\x04 \x03(\r\"\x8e\x03\n+CPlayer_GetTopAchievementsForGames_Response\x12@\n\x05games\x18\x01 \x03(\x0b\x32\x31.CPlayer_GetTopAchievementsForGames_Response.Game\x1a\x98\x01\n\x0b\x41\x63hievement\x12\x0e\n\x06statid\x18\x01 \x01(\r\x12\x0b\n\x03\x62it\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x11\n\ticon_gray\x18\x06 \x01(\t\x12\x0e\n\x06hidden\x18\x07 \x01(\x08\x12\x1f\n\x17player_percent_unlocked\x18\x08 \x01(\t\x1a\x81\x01\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1a\n\x12total_achievements\x18\x02 \x01(\r\x12N\n\x0c\x61\x63hievements\x18\x03 \x03(\x0b\x32\x38.CPlayer_GetTopAchievementsForGames_Response.Achievement\"{\n\'CPlayer_GetAchievementsProgress_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x0e\n\x06\x61ppids\x18\x03 \x03(\r\x12\x1d\n\x15include_unvetted_apps\x18\x04 \x01(\x08\"\x9d\x02\n(CPlayer_GetAchievementsProgress_Response\x12[\n\x14\x61\x63hievement_progress\x18\x01 \x03(\x0b\x32=.CPlayer_GetAchievementsProgress_Response.AchievementProgress\x1a\x93\x01\n\x13\x41\x63hievementProgress\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08unlocked\x18\x02 \x01(\r\x12\r\n\x05total\x18\x03 \x01(\r\x12\x12\n\npercentage\x18\x04 \x01(\x02\x12\x14\n\x0c\x61ll_unlocked\x18\x05 \x01(\x08\x12\x12\n\ncache_time\x18\x06 \x01(\r\x12\x0e\n\x06vetted\x18\x07 \x01(\x08\"F\n#CPlayer_GetGameAchievements_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08language\x18\x02 \x01(\t\"\x98\x02\n$CPlayer_GetGameAchievements_Response\x12G\n\x0c\x61\x63hievements\x18\x01 \x03(\x0b\x32\x31.CPlayer_GetGameAchievements_Response.Achievement\x1a\xa6\x01\n\x0b\x41\x63hievement\x12\x15\n\rinternal_name\x18\x01 \x01(\t\x12\x16\n\x0elocalized_name\x18\x02 \x01(\t\x12\x16\n\x0elocalized_desc\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x11\n\ticon_gray\x18\x05 \x01(\t\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x1f\n\x17player_percent_unlocked\x18\x07 \x01(\t\"3\n CPlayer_GetFavoriteBadge_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\"\xb0\x01\n!CPlayer_GetFavoriteBadge_Response\x12\x1a\n\x12has_favorite_badge\x18\x01 \x01(\x08\x12\x0f\n\x07\x62\x61\x64geid\x18\x02 \x01(\r\x12\x17\n\x0f\x63ommunityitemid\x18\x03 \x01(\x04\x12\x11\n\titem_type\x18\x04 \x01(\r\x12\x14\n\x0c\x62order_color\x18\x05 \x01(\r\x12\r\n\x05\x61ppid\x18\x06 \x01(\r\x12\r\n\x05level\x18\x07 \x01(\r\"L\n CPlayer_SetFavoriteBadge_Request\x12\x17\n\x0f\x63ommunityitemid\x18\x01 \x01(\x04\x12\x0f\n\x07\x62\x61\x64geid\x18\x02 \x01(\r\"#\n!CPlayer_SetFavoriteBadge_Response\"\x8d\x01\n\'CPlayer_GetProfileCustomization_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\'\n\x1finclude_inactive_customizations\x18\x02 \x01(\x08\x12(\n include_purchased_customizations\x18\x03 \x01(\x08\"\xf2\x02\n\x18ProfileCustomizationSlot\x12\x0c\n\x04slot\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x17\n\x0fpublishedfileid\x18\x03 \x01(\x04\x12\x14\n\x0citem_assetid\x18\x04 \x01(\x04\x12\x16\n\x0eitem_contextid\x18\x05 \x01(\x04\x12\r\n\x05notes\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x11\n\taccountid\x18\x08 \x01(\r\x12\x0f\n\x07\x62\x61\x64geid\x18\t \x01(\r\x12\x14\n\x0c\x62order_color\x18\n \x01(\r\x12\x14\n\x0citem_classid\x18\x0b \x01(\x04\x12\x17\n\x0fitem_instanceid\x18\x0c \x01(\x04\x12V\n\x10\x62\x61n_check_result\x18\r \x01(\x0e\x32\x17.EBanContentCheckResult:#k_EBanContentCheckResult_NotScanned\x12\x13\n\x0breplay_year\x18\x0e \x01(\r\"\xbd\x02\n\x14ProfileCustomization\x12Z\n\x12\x63ustomization_type\x18\x01 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05large\x18\x02 \x01(\x08\x12(\n\x05slots\x18\x03 \x03(\x0b\x32\x19.ProfileCustomizationSlot\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12]\n\x13\x63ustomization_style\x18\x05 \x01(\x0e\x32\x1b.EProfileCustomizationStyle:#k_EProfileCustomizationStyleDefault\x12\x12\n\npurchaseid\x18\x06 \x01(\x04\x12\r\n\x05level\x18\x07 \x01(\r\"/\n\x0cProfileTheme\x12\x10\n\x08theme_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"1\n\x12ProfilePreferences\x12\x1b\n\x13hide_profile_awards\x18\x01 \x01(\x08\"\xc8\x03\n(CPlayer_GetProfileCustomization_Response\x12-\n\x0e\x63ustomizations\x18\x01 \x03(\x0b\x32\x15.ProfileCustomization\x12\x17\n\x0fslots_available\x18\x02 \x01(\r\x12$\n\rprofile_theme\x18\x03 \x01(\x0b\x32\r.ProfileTheme\x12\x62\n\x18purchased_customizations\x18\x04 \x03(\x0b\x32@.CPlayer_GetProfileCustomization_Response.PurchasedCustomization\x12\x30\n\x13profile_preferences\x18\x05 \x01(\x0b\x32\x13.ProfilePreferences\x1a\x97\x01\n\x16PurchasedCustomization\x12\x12\n\npurchaseid\x18\x01 \x01(\x04\x12Z\n\x12\x63ustomization_type\x18\x02 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05level\x18\x03 \x01(\r\"D\n1CPlayer_GetPurchasedProfileCustomizations_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xad\x02\n2CPlayer_GetPurchasedProfileCustomizations_Response\x12l\n\x18purchased_customizations\x18\x01 \x03(\x0b\x32J.CPlayer_GetPurchasedProfileCustomizations_Response.PurchasedCustomization\x1a\x88\x01\n\x16PurchasedCustomization\x12\x12\n\npurchaseid\x18\x01 \x01(\x04\x12Z\n\x12\x63ustomization_type\x18\x02 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\"O\n<CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xba\x04\n=CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response\x12w\n\x18purchased_customizations\x18\x01 \x03(\x0b\x32U.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.PurchasedCustomization\x12u\n\x17upgraded_customizations\x18\x02 \x03(\x0b\x32T.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response.UpgradedCustomization\x1a\x83\x01\n\x16PurchasedCustomization\x12Z\n\x12\x63ustomization_type\x18\x01 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x1a\x82\x01\n\x15UpgradedCustomization\x12Z\n\x12\x63ustomization_type\x18\x01 \x01(\x0e\x32\x1a.EProfileCustomizationType:\"k_EProfileCustomizationTypeInvalid\x12\r\n\x05level\x18\x02 \x01(\r\"+\n)CPlayer_GetProfileThemesAvailable_Request\"S\n*CPlayer_GetProfileThemesAvailable_Response\x12%\n\x0eprofile_themes\x18\x01 \x03(\x0b\x32\r.ProfileTheme\"3\n\x1f\x43Player_SetProfileTheme_Request\x12\x10\n\x08theme_id\x18\x01 \x01(\t\"\"\n CPlayer_SetProfileTheme_Response\"Y\n%CPlayer_SetProfilePreferences_Request\x12\x30\n\x13profile_preferences\x18\x01 \x01(\x0b\x32\x13.ProfilePreferences\"(\n&CPlayer_SetProfilePreferences_Response\"I\n#CPlayer_PostStatusToFriends_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x13\n\x0bstatus_text\x18\x02 \x01(\t\"&\n$CPlayer_PostStatusToFriends_Response\"B\n\x1f\x43Player_GetPostedStatus_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x0e\n\x06postid\x18\x02 \x01(\x04\"z\n CPlayer_GetPostedStatus_Response\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0e\n\x06postid\x18\x02 \x01(\x04\x12\x13\n\x0bstatus_text\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x04 \x01(\x08\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\"4\n\"CPlayer_DeletePostedStatus_Request\x12\x0e\n\x06postid\x18\x01 \x01(\x04\"%\n#CPlayer_DeletePostedStatus_Response\"=\n\"CPlayer_GetLastPlayedTimes_Request\x12\x17\n\x0fmin_last_played\x18\x01 \x01(\r\"\xe1\x04\n#CPlayer_GetLastPlayedTimes_Response\x12\x38\n\x05games\x18\x01 \x03(\x0b\x32).CPlayer_GetLastPlayedTimes_Response.Game\x1a\xff\x03\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x15\n\rlast_playtime\x18\x02 \x01(\r\x12\x17\n\x0fplaytime_2weeks\x18\x03 \x01(\x05\x12\x18\n\x10playtime_forever\x18\x04 \x01(\x05\x12\x16\n\x0e\x66irst_playtime\x18\x05 \x01(\r\x12 \n\x18playtime_windows_forever\x18\x06 \x01(\x05\x12\x1c\n\x14playtime_mac_forever\x18\x07 \x01(\x05\x12\x1e\n\x16playtime_linux_forever\x18\x08 \x01(\x05\x12\x1d\n\x15playtime_deck_forever\x18\x10 \x01(\x05\x12\x1e\n\x16\x66irst_windows_playtime\x18\t \x01(\r\x12\x1a\n\x12\x66irst_mac_playtime\x18\n \x01(\r\x12\x1c\n\x14\x66irst_linux_playtime\x18\x0b \x01(\r\x12\x1b\n\x13\x66irst_deck_playtime\x18\x11 \x01(\r\x12\x1d\n\x15last_windows_playtime\x18\x0c \x01(\r\x12\x19\n\x11last_mac_playtime\x18\r \x01(\r\x12\x1b\n\x13last_linux_playtime\x18\x0e \x01(\r\x12\x1a\n\x12last_deck_playtime\x18\x12 \x01(\r\x12\x1d\n\x15playtime_disconnected\x18\x0f \x01(\r\"$\n\"CPlayer_GetTimeSSAAccepted_Request\"z\n#CPlayer_GetTimeSSAAccepted_Response\x12\x19\n\x11time_ssa_accepted\x18\x01 \x01(\r\x12\x18\n\x10time_ssa_updated\x18\x02 \x01(\r\x12\x1e\n\x16time_chinassa_accepted\x18\x03 \x01(\r\"w\n\x19\x43Player_AcceptSSA_Request\x12\x41\n\x0e\x61greement_type\x18\x01 \x01(\x0e\x32\x0f.EAgreementType:\x18k_EAgreementType_Invalid\x12\x17\n\x0ftime_signed_utc\x18\x02 \x01(\r\"\x1c\n\x1a\x43Player_AcceptSSA_Response\"!\n\x1f\x43Player_GetNicknameList_Request\"\x9e\x01\n CPlayer_GetNicknameList_Response\x12\x43\n\tnicknames\x18\x01 \x03(\x0b\x32\x30.CPlayer_GetNicknameList_Response.PlayerNickname\x1a\x35\n\x0ePlayerNickname\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12\x10\n\x08nickname\x18\x02 \x01(\t\")\n\'CPlayer_GetPerFriendPreferences_Request\"\xd1\x05\n\x14PerFriendPreferences\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12_\n\x18notifications_showingame\x18\x03 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12_\n\x18notifications_showonline\x18\x04 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12\x61\n\x1anotifications_showmessages\x18\x05 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12X\n\x11sounds_showingame\x18\x06 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12X\n\x11sounds_showonline\x18\x07 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12Z\n\x13sounds_showmessages\x18\x08 \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\x12_\n\x18notifications_sendmobile\x18\t \x01(\x0e\x32\x15.ENotificationSetting:&k_ENotificationSettingNotifyUseDefault\"V\n(CPlayer_GetPerFriendPreferences_Response\x12*\n\x0bpreferences\x18\x01 \x03(\x0b\x32\x15.PerFriendPreferences\"U\n\'CPlayer_SetPerFriendPreferences_Request\x12*\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x15.PerFriendPreferences\"*\n(CPlayer_SetPerFriendPreferences_Response\",\n\x19\x43Player_AddFriend_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"^\n\x1a\x43Player_AddFriend_Response\x12\x13\n\x0binvite_sent\x18\x01 \x01(\x08\x12\x1b\n\x13\x66riend_relationship\x18\x02 \x01(\r\x12\x0e\n\x06result\x18\x03 \x01(\x05\"/\n\x1c\x43Player_RemoveFriend_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"<\n\x1d\x43Player_RemoveFriend_Response\x12\x1b\n\x13\x66riend_relationship\x18\x01 \x01(\r\"A\n\x1c\x43Player_IgnoreFriend_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08unignore\x18\x02 \x01(\x08\"<\n\x1d\x43Player_IgnoreFriend_Response\x12\x1b\n\x13\x66riend_relationship\x18\x01 \x01(\r\")\n\'CPlayer_GetCommunityPreferences_Request\"\x86\x02\n\x1c\x43Player_CommunityPreferences\x12%\n\x16parenthesize_nicknames\x18\x04 \x01(\x08:\x05\x66\x61lse\x12V\n\x13text_filter_setting\x18\x05 \x01(\x0e\x32\x13.ETextFilterSetting:$k_ETextFilterSettingSteamLabOptedOut\x12(\n\x1atext_filter_ignore_friends\x18\x06 \x01(\x08:\x04true\x12\"\n\x1atext_filter_words_revision\x18\x07 \x01(\r\x12\x19\n\x11timestamp_updated\x18\x03 \x01(\r\"\xa9\x01\n(CPlayer_GetCommunityPreferences_Response\x12\x32\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1d.CPlayer_CommunityPreferences\x12I\n\x1e\x63ontent_descriptor_preferences\x18\x02 \x01(\x0b\x32!.UserContentDescriptorPreferences\"]\n\'CPlayer_SetCommunityPreferences_Request\x12\x32\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1d.CPlayer_CommunityPreferences\"*\n(CPlayer_SetCommunityPreferences_Response\"$\n\"CPlayer_GetTextFilterWords_Request\"\x8e\x01\n\x17\x43Player_TextFilterWords\x12\'\n\x1ftext_filter_custom_banned_words\x18\x01 \x03(\t\x12&\n\x1etext_filter_custom_clean_words\x18\x02 \x03(\t\x12\"\n\x1atext_filter_words_revision\x18\x03 \x01(\r\"N\n#CPlayer_GetTextFilterWords_Response\x12\'\n\x05words\x18\x01 \x01(\x0b\x32\x18.CPlayer_TextFilterWords\"@\n,CPlayer_GetNewSteamAnnouncementState_Request\x12\x10\n\x08language\x18\x01 \x01(\x05\"\xe9\x01\n-CPlayer_GetNewSteamAnnouncementState_Response\x12P\n\x05state\x18\x01 \x01(\x0e\x32\x1b.ENewSteamAnnouncementState:$k_ENewSteamAnnouncementState_Invalid\x12\x1d\n\x15\x61nnouncement_headline\x18\x02 \x01(\t\x12\x18\n\x10\x61nnouncement_url\x18\x03 \x01(\t\x12\x13\n\x0btime_posted\x18\x04 \x01(\r\x12\x18\n\x10\x61nnouncement_gid\x18\x05 \x01(\x04\"`\n/CPlayer_UpdateSteamAnnouncementLastRead_Request\x12\x18\n\x10\x61nnouncement_gid\x18\x01 \x01(\x04\x12\x13\n\x0btime_posted\x18\x02 \x01(\r\"2\n0CPlayer_UpdateSteamAnnouncementLastRead_Response\"$\n\"CPlayer_GetPrivacySettings_Request\"\xcc\x01\n\x10\x43PrivacySettings\x12\x15\n\rprivacy_state\x18\x01 \x01(\x05\x12\x1f\n\x17privacy_state_inventory\x18\x02 \x01(\x05\x12\x1b\n\x13privacy_state_gifts\x18\x03 \x01(\x05\x12 \n\x18privacy_state_ownedgames\x18\x04 \x01(\x05\x12\x1e\n\x16privacy_state_playtime\x18\x05 \x01(\x05\x12!\n\x19privacy_state_friendslist\x18\x06 \x01(\x05\"R\n#CPlayer_GetPrivacySettings_Response\x12+\n\x10privacy_settings\x18\x01 \x01(\x0b\x32\x11.CPrivacySettings\"3\n\"CPlayer_GetDurationControl_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\xf0\x01\n#CPlayer_GetDurationControl_Response\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\x12\x0f\n\x07seconds\x18\x02 \x01(\x05\x12\x15\n\rseconds_today\x18\x03 \x01(\x05\x12\x1d\n\x15is_steamchina_account\x18\x04 \x01(\x08\x12\x17\n\x0fis_age_verified\x18\x05 \x01(\x08\x12\x1d\n\x15seconds_allowed_today\x18\x06 \x01(\r\x12 \n\x18\x61ge_verification_pending\x18\x07 \x01(\x08\x12\x14\n\x0c\x62lock_minors\x18\x08 \x01(\x08\"\xe7\x01\n*CPlayer_RecordDisconnectedPlaytime_Request\x12N\n\rplay_sessions\x18\x03 \x03(\x0b\x32\x37.CPlayer_RecordDisconnectedPlaytime_Request.PlayHistory\x1ai\n\x0bPlayHistory\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1a\n\x12session_time_start\x18\x02 \x01(\r\x12\x0f\n\x07seconds\x18\x03 \x01(\r\x12\x0f\n\x07offline\x18\x04 \x01(\x08\x12\r\n\x05owner\x18\x05 \x01(\r\"-\n+CPlayer_RecordDisconnectedPlaytime_Response\"`\n$CPlayer_LastPlayedTimes_Notification\x12\x38\n\x05games\x18\x01 \x03(\x0b\x32).CPlayer_GetLastPlayedTimes_Response.Game\"j\n*CPlayer_FriendNicknameChanged_Notification\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x17\n\x0fis_echo_to_self\x18\x03 \x01(\x08\"K\n6CPlayer_FriendEquippedProfileItemsChanged_Notification\x12\x11\n\taccountid\x18\x01 \x01(\x07\"\xea\x01\n.CPlayer_NewSteamAnnouncementState_Notification\x12P\n\x05state\x18\x01 \x01(\x0e\x32\x1b.ENewSteamAnnouncementState:$k_ENewSteamAnnouncementState_Invalid\x12\x1d\n\x15\x61nnouncement_headline\x18\x02 \x01(\t\x12\x18\n\x10\x61nnouncement_url\x18\x03 \x01(\t\x12\x13\n\x0btime_posted\x18\x04 \x01(\r\x12\x18\n\x10\x61nnouncement_gid\x18\x05 \x01(\x04\"\xb1\x01\n0CPlayer_CommunityPreferencesChanged_Notification\x12\x32\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1d.CPlayer_CommunityPreferences\x12I\n\x1e\x63ontent_descriptor_preferences\x18\x02 \x01(\x0b\x32!.UserContentDescriptorPreferences\"V\n+CPlayer_TextFilterWordsChanged_Notification\x12\'\n\x05words\x18\x01 \x01(\x0b\x32\x18.CPlayer_TextFilterWords\"q\n0CPlayer_PerFriendPreferencesChanged_Notification\x12\x11\n\taccountid\x18\x01 \x01(\x07\x12*\n\x0bpreferences\x18\x02 \x01(\x0b\x32\x15.PerFriendPreferences\"Z\n+CPlayer_PrivacySettingsChanged_Notification\x12+\n\x10privacy_settings\x18\x01 \x01(\x0b\x32\x11.CPrivacySettings*\x99\x02\n\x1a\x45ProfileCustomizationStyle\x12\'\n#k_EProfileCustomizationStyleDefault\x10\x00\x12(\n$k_EProfileCustomizationStyleSelected\x10\x01\x12&\n\"k_EProfileCustomizationStyleRarest\x10\x02\x12*\n&k_EProfileCustomizationStyleMostRecent\x10\x03\x12&\n\"k_EProfileCustomizationStyleRandom\x10\x04\x12,\n(k_EProfileCustomizationStyleHighestRated\x10\x05*v\n\x0e\x45\x41greementType\x12%\n\x18k_EAgreementType_Invalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1e\n\x1ak_EAgreementType_GlobalSSA\x10\x00\x12\x1d\n\x19k_EAgreementType_ChinaSSA\x10\x01*\x85\x01\n\x14\x45NotificationSetting\x12*\n&k_ENotificationSettingNotifyUseDefault\x10\x00\x12 \n\x1ck_ENotificationSettingAlways\x10\x01\x12\x1f\n\x1bk_ENotificationSettingNever\x10\x02*\xb0\x01\n\x12\x45TextFilterSetting\x12(\n$k_ETextFilterSettingSteamLabOptedOut\x10\x00\x12\x1f\n\x1bk_ETextFilterSettingEnabled\x10\x01\x12-\n)k_ETextFilterSettingEnabledAllowProfanity\x10\x02\x12 \n\x1ck_ETextFilterSettingDisabled\x10\x03\x32\xd2+\n\x06Player\x12\x8c\x01\n!GetRecentPlaytimeSessionsForChild\x12\x32.CPlayer_GetRecentPlaytimeSessionsForChild_Request\x1a\x33.CPlayer_GetRecentPlaytimeSessionsForChild_Response\x12\x65\n\x14GetPlayerLinkDetails\x12%.CPlayer_GetPlayerLinkDetails_Request\x1a&.CPlayer_GetPlayerLinkDetails_Response\x12\x8f\x01\n\"GetMutualFriendsForIncomingInvites\x12\x33.CPlayer_GetMutualFriendsForIncomingInvites_Request\x1a\x34.CPlayer_GetMutualFriendsForIncomingInvites_Response\x12P\n\rGetOwnedGames\x12\x1e.CPlayer_GetOwnedGames_Request\x1a\x1f.CPlayer_GetOwnedGames_Response\x12J\n\x0bGetPlayNext\x12\x1c.CPlayer_GetPlayNext_Request\x1a\x1d.CPlayer_GetPlayNext_Response\x12k\n\x16GetFriendsGameplayInfo\x12\'.CPlayer_GetFriendsGameplayInfo_Request\x1a(.CPlayer_GetFriendsGameplayInfo_Response\x12_\n\x12GetGameBadgeLevels\x12#.CPlayer_GetGameBadgeLevels_Request\x1a$.CPlayer_GetGameBadgeLevels_Response\x12\x65\n\x14GetProfileBackground\x12%.CPlayer_GetProfileBackground_Request\x1a&.CPlayer_GetProfileBackground_Response\x12\x65\n\x14SetProfileBackground\x12%.CPlayer_SetProfileBackground_Request\x1a&.CPlayer_SetProfileBackground_Response\x12q\n\x18GetMiniProfileBackground\x12).CPlayer_GetMiniProfileBackground_Request\x1a*.CPlayer_GetMiniProfileBackground_Response\x12q\n\x18SetMiniProfileBackground\x12).CPlayer_SetMiniProfileBackground_Request\x1a*.CPlayer_SetMiniProfileBackground_Response\x12S\n\x0eGetAvatarFrame\x12\x1f.CPlayer_GetAvatarFrame_Request\x1a .CPlayer_GetAvatarFrame_Response\x12S\n\x0eSetAvatarFrame\x12\x1f.CPlayer_SetAvatarFrame_Request\x1a .CPlayer_SetAvatarFrame_Response\x12\\\n\x11GetAnimatedAvatar\x12\".CPlayer_GetAnimatedAvatar_Request\x1a#.CPlayer_GetAnimatedAvatar_Response\x12\\\n\x11SetAnimatedAvatar\x12\".CPlayer_SetAnimatedAvatar_Request\x1a#.CPlayer_SetAnimatedAvatar_Response\x12q\n\x18GetSteamDeckKeyboardSkin\x12).CPlayer_GetSteamDeckKeyboardSkin_Request\x1a*.CPlayer_GetSteamDeckKeyboardSkin_Response\x12q\n\x18SetSteamDeckKeyboardSkin\x12).CPlayer_SetSteamDeckKeyboardSkin_Request\x1a*.CPlayer_SetSteamDeckKeyboardSkin_Response\x12\x65\n\x14GetProfileItemsOwned\x12%.CPlayer_GetProfileItemsOwned_Request\x1a&.CPlayer_GetProfileItemsOwned_Response\x12n\n\x17GetProfileItemsEquipped\x12(.CPlayer_GetProfileItemsEquipped_Request\x1a).CPlayer_GetProfileItemsEquipped_Response\x12z\n\x1bSetEquippedProfileItemFlags\x12,.CPlayer_SetEquippedProfileItemFlags_Request\x1a-.CPlayer_SetEquippedProfileItemFlags_Response\x12V\n\x0fGetEmoticonList\x12 .CPlayer_GetEmoticonList_Request\x1a!.CPlayer_GetEmoticonList_Response\x12t\n\x19GetCommunityBadgeProgress\x12*.CPlayer_GetCommunityBadgeProgress_Request\x1a+.CPlayer_GetCommunityBadgeProgress_Response\x12w\n\x1aGetTopAchievementsForGames\x12+.CPlayer_GetTopAchievementsForGames_Request\x1a,.CPlayer_GetTopAchievementsForGames_Response\x12n\n\x17GetAchievementsProgress\x12(.CPlayer_GetAchievementsProgress_Request\x1a).CPlayer_GetAchievementsProgress_Response\x12\x62\n\x13GetGameAchievements\x12$.CPlayer_GetGameAchievements_Request\x1a%.CPlayer_GetGameAchievements_Response\x12Y\n\x10GetFavoriteBadge\x12!.CPlayer_GetFavoriteBadge_Request\x1a\".CPlayer_GetFavoriteBadge_Response\x12Y\n\x10SetFavoriteBadge\x12!.CPlayer_SetFavoriteBadge_Request\x1a\".CPlayer_SetFavoriteBadge_Response\x12n\n\x17GetProfileCustomization\x12(.CPlayer_GetProfileCustomization_Request\x1a).CPlayer_GetProfileCustomization_Response\x12\x8c\x01\n!GetPurchasedProfileCustomizations\x12\x32.CPlayer_GetPurchasedProfileCustomizations_Request\x1a\x33.CPlayer_GetPurchasedProfileCustomizations_Response\x12\xad\x01\n,GetPurchasedAndUpgradedProfileCustomizations\x12=.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Request\x1a>.CPlayer_GetPurchasedAndUpgradedProfileCustomizations_Response\x12t\n\x19GetProfileThemesAvailable\x12*.CPlayer_GetProfileThemesAvailable_Request\x1a+.CPlayer_GetProfileThemesAvailable_Response\x12V\n\x0fSetProfileTheme\x12 .CPlayer_SetProfileTheme_Request\x1a!.CPlayer_SetProfileTheme_Response\x12h\n\x15SetProfilePreferences\x12&.CPlayer_SetProfilePreferences_Request\x1a\'.CPlayer_SetProfilePreferences_Response\x12\x62\n\x13PostStatusToFriends\x12$.CPlayer_PostStatusToFriends_Request\x1a%.CPlayer_PostStatusToFriends_Response\x12V\n\x0fGetPostedStatus\x12 .CPlayer_GetPostedStatus_Request\x1a!.CPlayer_GetPostedStatus_Response\x12_\n\x12\x44\x65letePostedStatus\x12#.CPlayer_DeletePostedStatus_Request\x1a$.CPlayer_DeletePostedStatus_Response\x12\x65\n\x18\x43lientGetLastPlayedTimes\x12#.CPlayer_GetLastPlayedTimes_Request\x1a$.CPlayer_GetLastPlayedTimes_Response\x12_\n\x12GetTimeSSAAccepted\x12#.CPlayer_GetTimeSSAAccepted_Request\x1a$.CPlayer_GetTimeSSAAccepted_Response\x12\x44\n\tAcceptSSA\x12\x1a.CPlayer_AcceptSSA_Request\x1a\x1b.CPlayer_AcceptSSA_Response\x12V\n\x0fGetNicknameList\x12 .CPlayer_GetNicknameList_Request\x1a!.CPlayer_GetNicknameList_Response\x12n\n\x17GetPerFriendPreferences\x12(.CPlayer_GetPerFriendPreferences_Request\x1a).CPlayer_GetPerFriendPreferences_Response\x12n\n\x17SetPerFriendPreferences\x12(.CPlayer_SetPerFriendPreferences_Request\x1a).CPlayer_SetPerFriendPreferences_Response\x12\x44\n\tAddFriend\x12\x1a.CPlayer_AddFriend_Request\x1a\x1b.CPlayer_AddFriend_Response\x12M\n\x0cRemoveFriend\x12\x1d.CPlayer_RemoveFriend_Request\x1a\x1e.CPlayer_RemoveFriend_Response\x12M\n\x0cIgnoreFriend\x12\x1d.CPlayer_IgnoreFriend_Request\x1a\x1e.CPlayer_IgnoreFriend_Response\x12n\n\x17GetCommunityPreferences\x12(.CPlayer_GetCommunityPreferences_Request\x1a).CPlayer_GetCommunityPreferences_Response\x12n\n\x17SetCommunityPreferences\x12(.CPlayer_SetCommunityPreferences_Request\x1a).CPlayer_SetCommunityPreferences_Response\x12_\n\x12GetTextFilterWords\x12#.CPlayer_GetTextFilterWords_Request\x1a$.CPlayer_GetTextFilterWords_Response\x12}\n\x1cGetNewSteamAnnouncementState\x12-.CPlayer_GetNewSteamAnnouncementState_Request\x1a..CPlayer_GetNewSteamAnnouncementState_Response\x12\x86\x01\n\x1fUpdateSteamAnnouncementLastRead\x12\x30.CPlayer_UpdateSteamAnnouncementLastRead_Request\x1a\x31.CPlayer_UpdateSteamAnnouncementLastRead_Response\x12_\n\x12GetPrivacySettings\x12#.CPlayer_GetPrivacySettings_Request\x1a$.CPlayer_GetPrivacySettings_Response\x12_\n\x12GetDurationControl\x12#.CPlayer_GetDurationControl_Request\x1a$.CPlayer_GetDurationControl_Response\x12w\n\x1aRecordDisconnectedPlaytime\x12+.CPlayer_RecordDisconnectedPlaytime_Request\x1a,.CPlayer_RecordDisconnectedPlaytime_Response2\x93\x06\n\x0cPlayerClient\x12K\n\x15NotifyLastPlayedTimes\x12%.CPlayer_LastPlayedTimes_Notification\x1a\x0b.NoResponse\x12W\n\x1bNotifyFriendNicknameChanged\x12+.CPlayer_FriendNicknameChanged_Notification\x1a\x0b.NoResponse\x12o\n\'NotifyFriendEquippedProfileItemsChanged\x12\x37.CPlayer_FriendEquippedProfileItemsChanged_Notification\x1a\x0b.NoResponse\x12_\n\x1fNotifyNewSteamAnnouncementState\x12/.CPlayer_NewSteamAnnouncementState_Notification\x1a\x0b.NoResponse\x12\x63\n!NotifyCommunityPreferencesChanged\x12\x31.CPlayer_CommunityPreferencesChanged_Notification\x1a\x0b.NoResponse\x12Y\n\x1cNotifyTextFilterWordsChanged\x12,.CPlayer_TextFilterWordsChanged_Notification\x1a\x0b.NoResponse\x12\x63\n!NotifyPerFriendPreferencesChanged\x12\x31.CPlayer_PerFriendPreferencesChanged_Notification\x1a\x0b.NoResponse\x12`\n#NotifyPrivacyPrivacySettingsChanged\x12,.CPlayer_PrivacySettingsChanged_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_player_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _PLAYERCLIENT._options = None
  _PLAYERCLIENT._serialized_options = b'\300\265\030\002'
  _EPROFILECUSTOMIZATIONSTYLE._serialized_start=17835
  _EPROFILECUSTOMIZATIONSTYLE._serialized_end=18116
  _EAGREEMENTTYPE._serialized_start=18118
  _EAGREEMENTTYPE._serialized_end=18236
  _ENOTIFICATIONSETTING._serialized_start=18239
  _ENOTIFICATIONSETTING._serialized_end=18372
  _ETEXTFILTERSETTING._serialized_start=18375
  _ETEXTFILTERSETTING._serialized_end=18551
  _CPLAYER_GETRECENTPLAYTIMESESSIONSFORCHILD_REQUEST._serialized_start=103
  _CPLAYER_GETRECENTPLAYTIMESESSIONSFORCHILD_REQUEST._serialized_end=171
  _CPLAYER_GETRECENTPLAYTIMESESSIONSFORCHILD_RESPONSE._serialized_start=174
  _CPLAYER_GETRECENTPLAYTIMESESSIONSFORCHILD_RESPONSE._serialized_end=428
  _CPLAYER_GETRECENTPLAYTIMESESSIONSFORCHILD_RESPONSE_PLAYTIMESESSION._serialized_start=315
  _CPLAYER_GETRECENTPLAYTIMESESSIONSFORCHILD_RESPONSE_PLAYTIMESESSION._serialized_end=428
  _CPLAYER_GETPLAYERLINKDETAILS_REQUEST._serialized_start=430
  _CPLAYER_GETPLAYERLINKDETAILS_REQUEST._serialized_end=486
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE._serialized_start=489
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE._serialized_end=1710
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE_PLAYERLINKDETAILS._serialized_start=607
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE_PLAYERLINKDETAILS._serialized_end=1710
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE_PLAYERLINKDETAILS_ACCOUNTPUBLICDATA._serialized_start=825
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE_PLAYERLINKDETAILS_ACCOUNTPUBLICDATA._serialized_end=1088
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE_PLAYERLINKDETAILS_ACCOUNTPRIVATEDATA._serialized_start=1091
  _CPLAYER_GETPLAYERLINKDETAILS_RESPONSE_PLAYERLINKDETAILS_ACCOUNTPRIVATEDATA._serialized_end=1710
  _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_REQUEST._serialized_start=1712
  _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_REQUEST._serialized_end=1764
  _CPLAYER_INCOMINGINVITEMUTUALFRIENDLIST._serialized_start=1766
  _CPLAYER_INCOMINGINVITEMUTUALFRIENDLIST._serialized_end=1858
  _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_RESPONSE._serialized_start=1861
  _CPLAYER_GETMUTUALFRIENDSFORINCOMINGINVITES_RESPONSE._serialized_end=2001
  _CPLAYER_GETOWNEDGAMES_REQUEST._serialized_start=2004
  _CPLAYER_GETOWNEDGAMES_REQUEST._serialized_end=2247
  _CPLAYER_GETOWNEDGAMES_RESPONSE._serialized_start=2250
  _CPLAYER_GETOWNEDGAMES_RESPONSE._serialized_end=2847
  _CPLAYER_GETOWNEDGAMES_RESPONSE_GAME._serialized_start=2358
  _CPLAYER_GETOWNEDGAMES_RESPONSE_GAME._serialized_end=2847
  _CPLAYER_GETPLAYNEXT_REQUEST._serialized_start=2849
  _CPLAYER_GETPLAYNEXT_REQUEST._serialized_end=2926
  _CPLAYER_GETPLAYNEXT_RESPONSE._serialized_start=2928
  _CPLAYER_GETPLAYNEXT_RESPONSE._serialized_end=3000
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_REQUEST._serialized_start=3002
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_REQUEST._serialized_end=3057
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE._serialized_start=3060
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE._serialized_end=3810
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO._serialized_start=3588
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_FRIENDSGAMEPLAYINFO._serialized_end=3682
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_OWNGAMEPLAYINFO._serialized_start=3684
  _CPLAYER_GETFRIENDSGAMEPLAYINFO_RESPONSE_OWNGAMEPLAYINFO._serialized_end=3810
  _CPLAYER_GETGAMEBADGELEVELS_REQUEST._serialized_start=3812
  _CPLAYER_GETGAMEBADGELEVELS_REQUEST._serialized_end=3863
  _CPLAYER_GETGAMEBADGELEVELS_RESPONSE._serialized_start=3866
  _CPLAYER_GETGAMEBADGELEVELS_RESPONSE._serialized_end=4047
  _CPLAYER_GETGAMEBADGELEVELS_RESPONSE_BADGE._serialized_start=3987
  _CPLAYER_GETGAMEBADGELEVELS_RESPONSE_BADGE._serialized_end=4047
  _CPLAYER_GETPROFILEBACKGROUND_REQUEST._serialized_start=4049
  _CPLAYER_GETPROFILEBACKGROUND_REQUEST._serialized_end=4122
  _PROFILEITEM._serialized_start=4125
  _PROFILEITEM._serialized_end=4550
  _PROFILEITEM_PROFILECOLOR._serialized_start=4501
  _PROFILEITEM_PROFILECOLOR._serialized_end=4550
  _CPLAYER_GETPROFILEBACKGROUND_RESPONSE._serialized_start=4552
  _CPLAYER_GETPROFILEBACKGROUND_RESPONSE._serialized_end=4633
  _CPLAYER_SETPROFILEBACKGROUND_REQUEST._serialized_start=4635
  _CPLAYER_SETPROFILEBACKGROUND_REQUEST._serialized_end=4698
  _CPLAYER_SETPROFILEBACKGROUND_RESPONSE._serialized_start=4700
  _CPLAYER_SETPROFILEBACKGROUND_RESPONSE._serialized_end=4739
  _CPLAYER_GETMINIPROFILEBACKGROUND_REQUEST._serialized_start=4741
  _CPLAYER_GETMINIPROFILEBACKGROUND_REQUEST._serialized_end=4818
  _CPLAYER_GETMINIPROFILEBACKGROUND_RESPONSE._serialized_start=4820
  _CPLAYER_GETMINIPROFILEBACKGROUND_RESPONSE._serialized_end=4905
  _CPLAYER_SETMINIPROFILEBACKGROUND_REQUEST._serialized_start=4907
  _CPLAYER_SETMINIPROFILEBACKGROUND_REQUEST._serialized_end=4974
  _CPLAYER_SETMINIPROFILEBACKGROUND_RESPONSE._serialized_start=4976
  _CPLAYER_SETMINIPROFILEBACKGROUND_RESPONSE._serialized_end=5019
  _CPLAYER_GETAVATARFRAME_REQUEST._serialized_start=5021
  _CPLAYER_GETAVATARFRAME_REQUEST._serialized_end=5088
  _CPLAYER_GETAVATARFRAME_RESPONSE._serialized_start=5090
  _CPLAYER_GETAVATARFRAME_RESPONSE._serialized_end=5159
  _CPLAYER_SETAVATARFRAME_REQUEST._serialized_start=5161
  _CPLAYER_SETAVATARFRAME_REQUEST._serialized_end=5218
  _CPLAYER_SETAVATARFRAME_RESPONSE._serialized_start=5220
  _CPLAYER_SETAVATARFRAME_RESPONSE._serialized_end=5253
  _CPLAYER_GETANIMATEDAVATAR_REQUEST._serialized_start=5255
  _CPLAYER_GETANIMATEDAVATAR_REQUEST._serialized_end=5325
  _CPLAYER_GETANIMATEDAVATAR_RESPONSE._serialized_start=5327
  _CPLAYER_GETANIMATEDAVATAR_RESPONSE._serialized_end=5393
  _CPLAYER_SETANIMATEDAVATAR_REQUEST._serialized_start=5395
  _CPLAYER_SETANIMATEDAVATAR_REQUEST._serialized_end=5455
  _CPLAYER_SETANIMATEDAVATAR_RESPONSE._serialized_start=5457
  _CPLAYER_SETANIMATEDAVATAR_RESPONSE._serialized_end=5493
  _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_REQUEST._serialized_start=5495
  _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_REQUEST._serialized_end=5572
  _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_RESPONSE._serialized_start=5574
  _CPLAYER_GETSTEAMDECKKEYBOARDSKIN_RESPONSE._serialized_end=5665
  _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_REQUEST._serialized_start=5667
  _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_REQUEST._serialized_end=5734
  _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_RESPONSE._serialized_start=5736
  _CPLAYER_SETSTEAMDECKKEYBOARDSKIN_RESPONSE._serialized_end=5779
  _CPLAYER_GETPROFILEITEMSOWNED_REQUEST._serialized_start=5781
  _CPLAYER_GETPROFILEITEMSOWNED_REQUEST._serialized_end=5876
  _CPLAYER_GETPROFILEITEMSOWNED_RESPONSE._serialized_start=5879
  _CPLAYER_GETPROFILEITEMSOWNED_RESPONSE._serialized_end=6225
  _CPLAYER_GETPROFILEITEMSEQUIPPED_REQUEST._serialized_start=6227
  _CPLAYER_GETPROFILEITEMSEQUIPPED_REQUEST._serialized_end=6303
  _CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE._serialized_start=6306
  _CPLAYER_GETPROFILEITEMSEQUIPPED_RESPONSE._serialized_end=6600
  _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_REQUEST._serialized_start=6602
  _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_REQUEST._serialized_end=6687
  _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_RESPONSE._serialized_start=6689
  _CPLAYER_SETEQUIPPEDPROFILEITEMFLAGS_RESPONSE._serialized_end=6735
  _CPLAYER_GETEMOTICONLIST_REQUEST._serialized_start=6737
  _CPLAYER_GETEMOTICONLIST_REQUEST._serialized_end=6770
  _CPLAYER_GETEMOTICONLIST_RESPONSE._serialized_start=6773
  _CPLAYER_GETEMOTICONLIST_RESPONSE._serialized_end=6992
  _CPLAYER_GETEMOTICONLIST_RESPONSE_EMOTICON._serialized_start=6872
  _CPLAYER_GETEMOTICONLIST_RESPONSE_EMOTICON._serialized_end=6992
  _CPLAYER_GETCOMMUNITYBADGEPROGRESS_REQUEST._serialized_start=6994
  _CPLAYER_GETCOMMUNITYBADGEPROGRESS_REQUEST._serialized_end=7071
  _CPLAYER_GETCOMMUNITYBADGEPROGRESS_RESPONSE._serialized_start=7074
  _CPLAYER_GETCOMMUNITYBADGEPROGRESS_RESPONSE._serialized_end=7230
  _CPLAYER_GETCOMMUNITYBADGEPROGRESS_RESPONSE_QUEST._serialized_start=7187
  _CPLAYER_GETCOMMUNITYBADGEPROGRESS_RESPONSE_QUEST._serialized_end=7230
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_REQUEST._serialized_start=7232
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_REQUEST._serialized_end=7353
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_RESPONSE._serialized_start=7356
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_RESPONSE._serialized_end=7754
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_RESPONSE_ACHIEVEMENT._serialized_start=7470
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_RESPONSE_ACHIEVEMENT._serialized_end=7622
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_RESPONSE_GAME._serialized_start=7625
  _CPLAYER_GETTOPACHIEVEMENTSFORGAMES_RESPONSE_GAME._serialized_end=7754
  _CPLAYER_GETACHIEVEMENTSPROGRESS_REQUEST._serialized_start=7756
  _CPLAYER_GETACHIEVEMENTSPROGRESS_REQUEST._serialized_end=7879
  _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE._serialized_start=7882
  _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE._serialized_end=8167
  _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE_ACHIEVEMENTPROGRESS._serialized_start=8020
  _CPLAYER_GETACHIEVEMENTSPROGRESS_RESPONSE_ACHIEVEMENTPROGRESS._serialized_end=8167
  _CPLAYER_GETGAMEACHIEVEMENTS_REQUEST._serialized_start=8169
  _CPLAYER_GETGAMEACHIEVEMENTS_REQUEST._serialized_end=8239
  _CPLAYER_GETGAMEACHIEVEMENTS_RESPONSE._serialized_start=8242
  _CPLAYER_GETGAMEACHIEVEMENTS_RESPONSE._serialized_end=8522
  _CPLAYER_GETGAMEACHIEVEMENTS_RESPONSE_ACHIEVEMENT._serialized_start=8356
  _CPLAYER_GETGAMEACHIEVEMENTS_RESPONSE_ACHIEVEMENT._serialized_end=8522
  _CPLAYER_GETFAVORITEBADGE_REQUEST._serialized_start=8524
  _CPLAYER_GETFAVORITEBADGE_REQUEST._serialized_end=8575
  _CPLAYER_GETFAVORITEBADGE_RESPONSE._serialized_start=8578
  _CPLAYER_GETFAVORITEBADGE_RESPONSE._serialized_end=8754
  _CPLAYER_SETFAVORITEBADGE_REQUEST._serialized_start=8756
  _CPLAYER_SETFAVORITEBADGE_REQUEST._serialized_end=8832
  _CPLAYER_SETFAVORITEBADGE_RESPONSE._serialized_start=8834
  _CPLAYER_SETFAVORITEBADGE_RESPONSE._serialized_end=8869
  _CPLAYER_GETPROFILECUSTOMIZATION_REQUEST._serialized_start=8872
  _CPLAYER_GETPROFILECUSTOMIZATION_REQUEST._serialized_end=9013
  _PROFILECUSTOMIZATIONSLOT._serialized_start=9016
  _PROFILECUSTOMIZATIONSLOT._serialized_end=9386
  _PROFILECUSTOMIZATION._serialized_start=9389
  _PROFILECUSTOMIZATION._serialized_end=9706
  _PROFILETHEME._serialized_start=9708
  _PROFILETHEME._serialized_end=9755
  _PROFILEPREFERENCES._serialized_start=9757
  _PROFILEPREFERENCES._serialized_end=9806
  _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE._serialized_start=9809
  _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE._serialized_end=10265
  _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION._serialized_start=10114
  _CPLAYER_GETPROFILECUSTOMIZATION_RESPONSE_PURCHASEDCUSTOMIZATION._serialized_end=10265
  _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_REQUEST._serialized_start=10267
  _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_REQUEST._serialized_end=10335
  _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE._serialized_start=10338
  _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE._serialized_end=10639
  _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION._serialized_start=10114
  _CPLAYER_GETPURCHASEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION._serialized_end=10250
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_REQUEST._serialized_start=10641
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_REQUEST._serialized_end=10720
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE._serialized_start=10723
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE._serialized_end=11293
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION._serialized_start=11029
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_PURCHASEDCUSTOMIZATION._serialized_end=11160
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION._serialized_start=11163
  _CPLAYER_GETPURCHASEDANDUPGRADEDPROFILECUSTOMIZATIONS_RESPONSE_UPGRADEDCUSTOMIZATION._serialized_end=11293
  _CPLAYER_GETPROFILETHEMESAVAILABLE_REQUEST._serialized_start=11295
  _CPLAYER_GETPROFILETHEMESAVAILABLE_REQUEST._serialized_end=11338
  _CPLAYER_GETPROFILETHEMESAVAILABLE_RESPONSE._serialized_start=11340
  _CPLAYER_GETPROFILETHEMESAVAILABLE_RESPONSE._serialized_end=11423
  _CPLAYER_SETPROFILETHEME_REQUEST._serialized_start=11425
  _CPLAYER_SETPROFILETHEME_REQUEST._serialized_end=11476
  _CPLAYER_SETPROFILETHEME_RESPONSE._serialized_start=11478
  _CPLAYER_SETPROFILETHEME_RESPONSE._serialized_end=11512
  _CPLAYER_SETPROFILEPREFERENCES_REQUEST._serialized_start=11514
  _CPLAYER_SETPROFILEPREFERENCES_REQUEST._serialized_end=11603
  _CPLAYER_SETPROFILEPREFERENCES_RESPONSE._serialized_start=11605
  _CPLAYER_SETPROFILEPREFERENCES_RESPONSE._serialized_end=11645
  _CPLAYER_POSTSTATUSTOFRIENDS_REQUEST._serialized_start=11647
  _CPLAYER_POSTSTATUSTOFRIENDS_REQUEST._serialized_end=11720
  _CPLAYER_POSTSTATUSTOFRIENDS_RESPONSE._serialized_start=11722
  _CPLAYER_POSTSTATUSTOFRIENDS_RESPONSE._serialized_end=11760
  _CPLAYER_GETPOSTEDSTATUS_REQUEST._serialized_start=11762
  _CPLAYER_GETPOSTEDSTATUS_REQUEST._serialized_end=11828
  _CPLAYER_GETPOSTEDSTATUS_RESPONSE._serialized_start=11830
  _CPLAYER_GETPOSTEDSTATUS_RESPONSE._serialized_end=11952
  _CPLAYER_DELETEPOSTEDSTATUS_REQUEST._serialized_start=11954
  _CPLAYER_DELETEPOSTEDSTATUS_REQUEST._serialized_end=12006
  _CPLAYER_DELETEPOSTEDSTATUS_RESPONSE._serialized_start=12008
  _CPLAYER_DELETEPOSTEDSTATUS_RESPONSE._serialized_end=12045
  _CPLAYER_GETLASTPLAYEDTIMES_REQUEST._serialized_start=12047
  _CPLAYER_GETLASTPLAYEDTIMES_REQUEST._serialized_end=12108
  _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE._serialized_start=12111
  _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE._serialized_end=12720
  _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME._serialized_start=12209
  _CPLAYER_GETLASTPLAYEDTIMES_RESPONSE_GAME._serialized_end=12720
  _CPLAYER_GETTIMESSAACCEPTED_REQUEST._serialized_start=12722
  _CPLAYER_GETTIMESSAACCEPTED_REQUEST._serialized_end=12758
  _CPLAYER_GETTIMESSAACCEPTED_RESPONSE._serialized_start=12760
  _CPLAYER_GETTIMESSAACCEPTED_RESPONSE._serialized_end=12882
  _CPLAYER_ACCEPTSSA_REQUEST._serialized_start=12884
  _CPLAYER_ACCEPTSSA_REQUEST._serialized_end=13003
  _CPLAYER_ACCEPTSSA_RESPONSE._serialized_start=13005
  _CPLAYER_ACCEPTSSA_RESPONSE._serialized_end=13033
  _CPLAYER_GETNICKNAMELIST_REQUEST._serialized_start=13035
  _CPLAYER_GETNICKNAMELIST_REQUEST._serialized_end=13068
  _CPLAYER_GETNICKNAMELIST_RESPONSE._serialized_start=13071
  _CPLAYER_GETNICKNAMELIST_RESPONSE._serialized_end=13229
  _CPLAYER_GETNICKNAMELIST_RESPONSE_PLAYERNICKNAME._serialized_start=13176
  _CPLAYER_GETNICKNAMELIST_RESPONSE_PLAYERNICKNAME._serialized_end=13229
  _CPLAYER_GETPERFRIENDPREFERENCES_REQUEST._serialized_start=13231
  _CPLAYER_GETPERFRIENDPREFERENCES_REQUEST._serialized_end=13272
  _PERFRIENDPREFERENCES._serialized_start=13275
  _PERFRIENDPREFERENCES._serialized_end=13996
  _CPLAYER_GETPERFRIENDPREFERENCES_RESPONSE._serialized_start=13998
  _CPLAYER_GETPERFRIENDPREFERENCES_RESPONSE._serialized_end=14084
  _CPLAYER_SETPERFRIENDPREFERENCES_REQUEST._serialized_start=14086
  _CPLAYER_SETPERFRIENDPREFERENCES_REQUEST._serialized_end=14171
  _CPLAYER_SETPERFRIENDPREFERENCES_RESPONSE._serialized_start=14173
  _CPLAYER_SETPERFRIENDPREFERENCES_RESPONSE._serialized_end=14215
  _CPLAYER_ADDFRIEND_REQUEST._serialized_start=14217
  _CPLAYER_ADDFRIEND_REQUEST._serialized_end=14261
  _CPLAYER_ADDFRIEND_RESPONSE._serialized_start=14263
  _CPLAYER_ADDFRIEND_RESPONSE._serialized_end=14357
  _CPLAYER_REMOVEFRIEND_REQUEST._serialized_start=14359
  _CPLAYER_REMOVEFRIEND_REQUEST._serialized_end=14406
  _CPLAYER_REMOVEFRIEND_RESPONSE._serialized_start=14408
  _CPLAYER_REMOVEFRIEND_RESPONSE._serialized_end=14468
  _CPLAYER_IGNOREFRIEND_REQUEST._serialized_start=14470
  _CPLAYER_IGNOREFRIEND_REQUEST._serialized_end=14535
  _CPLAYER_IGNOREFRIEND_RESPONSE._serialized_start=14537
  _CPLAYER_IGNOREFRIEND_RESPONSE._serialized_end=14597
  _CPLAYER_GETCOMMUNITYPREFERENCES_REQUEST._serialized_start=14599
  _CPLAYER_GETCOMMUNITYPREFERENCES_REQUEST._serialized_end=14640
  _CPLAYER_COMMUNITYPREFERENCES._serialized_start=14643
  _CPLAYER_COMMUNITYPREFERENCES._serialized_end=14905
  _CPLAYER_GETCOMMUNITYPREFERENCES_RESPONSE._serialized_start=14908
  _CPLAYER_GETCOMMUNITYPREFERENCES_RESPONSE._serialized_end=15077
  _CPLAYER_SETCOMMUNITYPREFERENCES_REQUEST._serialized_start=15079
  _CPLAYER_SETCOMMUNITYPREFERENCES_REQUEST._serialized_end=15172
  _CPLAYER_SETCOMMUNITYPREFERENCES_RESPONSE._serialized_start=15174
  _CPLAYER_SETCOMMUNITYPREFERENCES_RESPONSE._serialized_end=15216
  _CPLAYER_GETTEXTFILTERWORDS_REQUEST._serialized_start=15218
  _CPLAYER_GETTEXTFILTERWORDS_REQUEST._serialized_end=15254
  _CPLAYER_TEXTFILTERWORDS._serialized_start=15257
  _CPLAYER_TEXTFILTERWORDS._serialized_end=15399
  _CPLAYER_GETTEXTFILTERWORDS_RESPONSE._serialized_start=15401
  _CPLAYER_GETTEXTFILTERWORDS_RESPONSE._serialized_end=15479
  _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_REQUEST._serialized_start=15481
  _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_REQUEST._serialized_end=15545
  _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_RESPONSE._serialized_start=15548
  _CPLAYER_GETNEWSTEAMANNOUNCEMENTSTATE_RESPONSE._serialized_end=15781
  _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_REQUEST._serialized_start=15783
  _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_REQUEST._serialized_end=15879
  _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_RESPONSE._serialized_start=15881
  _CPLAYER_UPDATESTEAMANNOUNCEMENTLASTREAD_RESPONSE._serialized_end=15931
  _CPLAYER_GETPRIVACYSETTINGS_REQUEST._serialized_start=15933
  _CPLAYER_GETPRIVACYSETTINGS_REQUEST._serialized_end=15969
  _CPRIVACYSETTINGS._serialized_start=15972
  _CPRIVACYSETTINGS._serialized_end=16176
  _CPLAYER_GETPRIVACYSETTINGS_RESPONSE._serialized_start=16178
  _CPLAYER_GETPRIVACYSETTINGS_RESPONSE._serialized_end=16260
  _CPLAYER_GETDURATIONCONTROL_REQUEST._serialized_start=16262
  _CPLAYER_GETDURATIONCONTROL_REQUEST._serialized_end=16313
  _CPLAYER_GETDURATIONCONTROL_RESPONSE._serialized_start=16316
  _CPLAYER_GETDURATIONCONTROL_RESPONSE._serialized_end=16556
  _CPLAYER_RECORDDISCONNECTEDPLAYTIME_REQUEST._serialized_start=16559
  _CPLAYER_RECORDDISCONNECTEDPLAYTIME_REQUEST._serialized_end=16790
  _CPLAYER_RECORDDISCONNECTEDPLAYTIME_REQUEST_PLAYHISTORY._serialized_start=16685
  _CPLAYER_RECORDDISCONNECTEDPLAYTIME_REQUEST_PLAYHISTORY._serialized_end=16790
  _CPLAYER_RECORDDISCONNECTEDPLAYTIME_RESPONSE._serialized_start=16792
  _CPLAYER_RECORDDISCONNECTEDPLAYTIME_RESPONSE._serialized_end=16837
  _CPLAYER_LASTPLAYEDTIMES_NOTIFICATION._serialized_start=16839
  _CPLAYER_LASTPLAYEDTIMES_NOTIFICATION._serialized_end=16935
  _CPLAYER_FRIENDNICKNAMECHANGED_NOTIFICATION._serialized_start=16937
  _CPLAYER_FRIENDNICKNAMECHANGED_NOTIFICATION._serialized_end=17043
  _CPLAYER_FRIENDEQUIPPEDPROFILEITEMSCHANGED_NOTIFICATION._serialized_start=17045
  _CPLAYER_FRIENDEQUIPPEDPROFILEITEMSCHANGED_NOTIFICATION._serialized_end=17120
  _CPLAYER_NEWSTEAMANNOUNCEMENTSTATE_NOTIFICATION._serialized_start=17123
  _CPLAYER_NEWSTEAMANNOUNCEMENTSTATE_NOTIFICATION._serialized_end=17357
  _CPLAYER_COMMUNITYPREFERENCESCHANGED_NOTIFICATION._serialized_start=17360
  _CPLAYER_COMMUNITYPREFERENCESCHANGED_NOTIFICATION._serialized_end=17537
  _CPLAYER_TEXTFILTERWORDSCHANGED_NOTIFICATION._serialized_start=17539
  _CPLAYER_TEXTFILTERWORDSCHANGED_NOTIFICATION._serialized_end=17625
  _CPLAYER_PERFRIENDPREFERENCESCHANGED_NOTIFICATION._serialized_start=17627
  _CPLAYER_PERFRIENDPREFERENCESCHANGED_NOTIFICATION._serialized_end=17740
  _CPLAYER_PRIVACYSETTINGSCHANGED_NOTIFICATION._serialized_start=17742
  _CPLAYER_PRIVACYSETTINGSCHANGED_NOTIFICATION._serialized_end=17832
  _PLAYER._serialized_start=18554
  _PLAYER._serialized_end=24140
  _PLAYERCLIENT._serialized_start=24143
  _PLAYERCLIENT._serialized_end=24930
_builder.BuildServices(DESCRIPTOR, 'steammessages_player_pb2', globals())
# @@protoc_insertion_point(module_scope)
